# CAATsLab (Orange add-on)

Add-on Orange Data Mining Computer Assisted Audit Techniques (CAATs).

## Instalasi dev
```bash
git clone https://github.com/deviardn/orange3-caatslab.git
cd orange3-CAATsLab
python -m venv .venv && source .venv/bin/activate  # (Windows: .venv\Scripts\activate)
pip install -U pip
pip install -e .
